@@ -39,15 +39,15 @@ unnest_characters <- function(
   collapse = NULL,
   ...
 ){
-  format <- match.arg(format)
+  format <- arg_match(format)
   unnest_tokens(tbl,
                 !! enquo(output),
                 !! enquo(input),
                 token = "characters",
                 format = format,
                 to_lower = to_lower,
-                drop = to_lower,
-                collapse = to_lower,
+                drop = drop,
+                collapse = collapse,
                 strip_non_alphanum = strip_non_alphanum,
                 ...
   )
@@ -70,15 +70,15 @@ unnest_character_shingles <- function(
   collapse = NULL,
   ...
 ){
-  format <- match.arg(format)
+  format <- arg_match(format)
   unnest_tokens(tbl,
                 !! enquo(output),
                 !! enquo(input),
                 token = "character_shingles",
                 format = format,
                 to_lower = to_lower,
-                drop = to_lower,
-                collapse = to_lower,
+                drop = drop,
+                collapse = collapse,
                 n = n,
                 n_min = n_min,
                 strip_non_alphanum = strip_non_alphanum,
